@@ -18,6 +18,7 @@
 package AI::MXNet::CudaModule;
 use strict;
 use warnings;
+use AI::MXNet::NS;
 use AI::MXNet::Base;
 use Mouse;
 use AI::MXNet::Function::Parameters;
@@ -195,6 +196,8 @@ method get_kernel(Str $name, Str $signature)
     return AI::MXNet::CudaKernel->new($handle, $name, \@is_ndarray, \@dtypes);
 }
 
+__PACKAGE__->AI::MXNet::NS::register('AI::MXNet');
+
 package AI::MXNet::CudaKernel;
 use Mouse;
 use AI::MXNet::Base;
@@ -296,4 +299,4 @@ method launch(
     );
 }
 
-1;
\ No newline at end of file
+1;
