@@ -18,11 +18,11 @@
 package AI::MXNet::Gluon::Data;
 use strict;
 use warnings;
+use AI::MXNet::NS;
 use AI::MXNet::Gluon::Data::Set;
 use AI::MXNet::Gluon::Data::Sampler;
 use AI::MXNet::Gluon::Data::Loader;
-use AI::MXNet::Gluon::Data::Vision;
-sub vision { 'AI::MXNet::Gluon::Data::Vision' }
+use AI::MXNet::Gluon::Data::Vision 'vision';
 
 1;
 
