@@ -272,7 +272,7 @@ sub BUILD
         if(defined $self->activation)
         {
             $self->act(
-                AI::MXNet::Gluon::NN::Activation->new(
+                AI::MXNet::Gluon::NN->Activation(
                     activation => $self->activation,
                     prefix => $self->activation.'_'
                 )
@@ -920,4 +920,4 @@ use overload '""' => sub {
 
 __PACKAGE__->register('AI::MXNet::Gluon::NN');
 
-1;
\ No newline at end of file
+1;
