@@ -156,7 +156,7 @@ sub BUILD
         if(defined $self->activation)
         {
             $self->act(
-                AI::MXNet::Gluon::NN::Activation->new(
+                AI::MXNet::Gluon::NN->Activation(
                     activation => $self->activation,
                     prefix     => $self->activation.'_'
                 )
@@ -1415,4 +1415,4 @@ method hybrid_forward(GluonClass $F, GluonInput $x)
 
 __PACKAGE__->register('AI::MXNet::Gluon::NN');
 
-1;
\ No newline at end of file
+1;
