@@ -18,17 +18,20 @@
 package AI::MXNet::Metric;
 use strict;
 use warnings;
+use AI::MXNet::NS;
 use AI::MXNet::Function::Parameters;
 use Scalar::Util qw/blessed/;
 use JSON::PP;
 
+=encoding utf-8
+
 =head1 NAME
 
     AI::MXNet::Metric - Evaluation Metric API.
 =head1 DESCRIPTION
 
     This module hosts all the evaluation metrics available to evaluate the performance of a learned model.
-    L<Python Docs|http://mxnet.incubator.apache.org/api/python/metric/metric.html>
+    L<Python Docs|https://mxnet.apache.org/api/python/metric/metric.html>
 =cut
 
 # Check to see if the two arrays are the same size.
@@ -294,7 +297,7 @@ method update(ArrayRef[AI::MXNet::NDArray] $labels, ArrayRef[AI::MXNet::NDArray]
 
     If top_k = 1, then TopKAccuracy is identical to Accuracy.
 
-    Parameters:	
+    Parameters:
     top_k(Int, default 1) – Whether targets are in top k predictions.
     name (Str, default 'top_k_accuracy') – Name of this metric instance for display.
 
