@@ -18,6 +18,7 @@
 package AI::MXNet::TestUtils;
 use strict;
 use warnings;
+use AI::MXNet 'mx';
 use PDL;
 use Carp qw(confess);
 use Scalar::Util qw(blessed);
@@ -26,10 +27,10 @@ use AI::MXNet::Function::Parameters;
 use AI::MXNet::Base;
 use Exporter;
 use base qw(Exporter);
-@AI::MXNet::TestUtils::EXPORT_OK = qw(same reldiff almost_equal GetMNIST_ubyte
-                                      GetCifar10 pdl_maximum pdl_minimum mlp2 conv dies_ok
-                                      check_consistency zip assert enumerate same_array dies_like allclose rand_shape_2d
-                                      rand_shape_3d rand_sparse_ndarray random_arrays rand_ndarray randint pdl);
+our @EXPORT_OK = qw(same reldiff almost_equal GetMNIST_ubyte
+                    GetCifar10 pdl_maximum pdl_minimum mlp2 conv dies_ok
+                    check_consistency zip assert enumerate same_array dies_like allclose rand_shape_2d
+                    rand_shape_3d rand_sparse_ndarray random_arrays rand_ndarray randint pdl);
 use constant default_numerical_threshold => 1e-6;
 =head1 NAME
 
@@ -45,9 +46,16 @@ use constant default_numerical_threshold => 1e-6;
     b : pdl
 =cut
 
+func isNaN(PDL $a)
+{
+    # Only NaN is not greater, equal to, or less than zero.
+    return !(($a > 0) + ($a <= 0));
+}
+
 func same(PDL $a, PDL $b)
 {
-    return ($a != $b)->sum == 0;
+    my $rv = ($a != $b) - isNaN($a) * isNaN($b);
+    return $rv->sum == 0;
 }
 
 =head2 allclose
